==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/ArrayLengthValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.ArrayLengthValue;
import io.ciera.tool.sql.ooaofooa.value.ArrayLengthValueSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class ArrayLengthValueSetImpl extends InstanceSet<ArrayLengthValueSet,ArrayLengthValue> implements ArrayLengthValueSet {

    // attributes
    @Override
    public void setArray_Value_ID( UniqueId ref_Array_Value_ID ) throws XtumlException {
        for ( ArrayLengthValue arraylengthvalue : this ) arraylengthvalue.setArray_Value_ID( ref_Array_Value_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ArrayLengthValue arraylengthvalue : this ) arraylengthvalue.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ArrayLengthValue arraylengthvalue : this ) valueset.add( arraylengthvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public ValueSet R840_returns_length_of_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ArrayLengthValue arraylengthvalue : this ) valueset.add( arraylengthvalue.R840_returns_length_of_Value() );
        return valueset;
    }


    @Override
    public ArrayLengthValue nullElement() {
        return ArrayLengthValueImpl.EMPTY_ARRAYLENGTHVALUE;
    }

    @Override
    public ArrayLengthValueSet emptySet() {
      return new ArrayLengthValueSetImpl();
    }

    @Override
    public ArrayLengthValueSet value() {
        return this;
    }

    @Override
    public List<ArrayLengthValue> elements() {
        return Arrays.asList(toArray(new ArrayLengthValue[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/ArrayLengthValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.ArrayLengthValue;
import io.ciera.tool.sql.ooaofooa.value.ArrayLengthValueSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ArrayLengthValueSetImpl extends InstanceSet<ArrayLengthValueSet,ArrayLengthValue> implements ArrayLengthValueSet {

    public ArrayLengthValueSetImpl() {
    }

    public ArrayLengthValueSetImpl(Comparator<? super ArrayLengthValue> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setArray_Value_ID( UniqueId ref_Array_Value_ID ) throws XtumlException {
        for ( ArrayLengthValue arraylengthvalue : this ) arraylengthvalue.setArray_Value_ID( ref_Array_Value_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ArrayLengthValue arraylengthvalue : this ) arraylengthvalue.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ArrayLengthValue arraylengthvalue : this ) valueset.add( arraylengthvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public ValueSet R840_returns_length_of_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ArrayLengthValue arraylengthvalue : this ) valueset.add( arraylengthvalue.R840_returns_length_of_Value() );
        return valueset;
    }


    @Override
    public ArrayLengthValue nullElement() {
        return ArrayLengthValueImpl.EMPTY_ARRAYLENGTHVALUE;
    }

    @Override
    public ArrayLengthValueSet emptySet() {
      return new ArrayLengthValueSetImpl();
    }

    @Override
    public ArrayLengthValueSet emptySet(Comparator<? super ArrayLengthValue> comp) {
      return new ArrayLengthValueSetImpl(comp);
    }

    @Override
    public ArrayLengthValueSet value() {
        return this;
    }

    @Override
    public List<ArrayLengthValue> elements() {
        return Arrays.asList(toArray(new ArrayLengthValue[0]));
    }

}
